"""
Alternative formulations of saturation vapour pressure temperature dependence approximations
"""
from .flatau_walko_cotton import FlatauWalkoCotton
from .august_roche_magnus import AugustRocheMagnus
from .lowe1977 import Lowe1977
from .murphy_koop_2005 import MurphyKoop2005
